Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8)

Unified Diff: pkg/analysis_server/lib/src/protocol.dart

Issue 532403002: Fix error handling in analysis.getError. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analysis_server/lib/src/protocol.dart
diff --git a/pkg/analysis_server/lib/src/protocol.dart b/pkg/analysis_server/lib/src/protocol.dart
index 779c6ec3bdb9b1a6648729c118f28e822038753d..9736af46f28be421d97e3de0f6b1581b7120e74e 100644
--- a/pkg/analysis_server/lib/src/protocol.dart
+++ b/pkg/analysis_server/lib/src/protocol.dart
@@ -851,15 +851,14 @@ class Response {
}
/**
* Initialize a newly created instance to represent an error condition caused
* by an error during `analysis.getErrors`.
*/
- Response.getErrorsError(Request request, String message,
- Map<String, Object> result)
+ Response.getErrorsInvalidFile(Request request)
: this(
request.id,
- error: new RequestError(RequestErrorCode.GET_ERRORS_ERROR, 'Error during `analysis.getErrors`: $message.'),
- result: result);
+ error: new RequestError(RequestErrorCode.GET_ERRORS_INVALID_FILE,
+ 'Error during `analysis.getErrors`: invalid file.'));
/**
* Initialize a newly created instance to represent an error condition caused
@@ -851,15 +851,14 @@ class Response {
}
/**
- * Initialize a newly created instance to represent an error condition caused
- * by an error during `analysis.getErrors`.
+ * Initialize a newly created instance to represent the
+ * GET_ERRORS_INVALID_FILE error condition.
*/

Powered by Google App Engine
This is Rietveld 408576698